@@ -151,17 +151,17 @@ class Block:
         # return f'{self.block_id}'
         return f'{self.__class__.__name__}'
 
-    # def command_send(self, command_name, command_params, context, block_context):
-    #     command_uuid = str(uuid4())
-    #     block_context['__deferred'] = command_uuid
-    #     self.executor.commands.append(
-    #         {
-    #             'name': command_name,
-    #             'params': command_params,
-    #             'uuid': command_uuid
-    #         }
-    #     )
-    #     raise DeferredOperation(command_uuid, context, block_context)
+    def command_send(self, command_name, command_params, context, block_context):
+        command_uuid = str(uuid4())
+        block_context['__deferred'] = command_uuid
+        context.operation['commands'].append(
+            {
+                'name': command_name,
+                'params': command_params,
+                'uuid': command_uuid
+            }
+        )
+        raise DeferredOperation(command_uuid, context, block_context)
 
     @staticmethod
     def command_sended(block_context):
@@ -188,7 +188,7 @@ class Block:
             return _data
         if _status.upper() == 'ERROR':
             if isinstance(_data, dict):
-                raise ExtException(**_data)
+                raise ExtException(parent=_data)
             else:
                 raise Exception(_data)
         raise ExtException(
@@ -223,7 +223,7 @@ class Block:
 
     # @classmethod
     # def set_thread_variable(cls, context, name, value):
-    #     context.block_context['__thread_vars'][name] = value
+    #     context.debug['__thread_vars'][name] = value
     #     cls.set_variable(context, name, value)
 
     @classmethod
