@@ -32,7 +32,7 @@ class MultiThreadLoop(Block):
         self._on_before_loop(node, path, context, block_context)
         var_name = node[0].text
         try:
-            node_loop = node[1]  # алгоритм внутри цикла
+            node_loop = self.get_node_statement(node)  # алгоритм внутри цикла
         except IndexError:  # не заполнено содержимое
             return
         if 'items' not in block_context:
@@ -47,7 +47,7 @@ class MultiThreadLoop(Block):
                 block_context['items'] = await self._get_items(context, block_context)
                 block_context['index'] = 0
                 if not len(block_context['items']):
-                    if context.commands:  # если список кончился, а команды не выполнены
+                    if context.operation['commands']:  # если список кончился, а команды не выполнены
                         raise LimitCommand()
                     return
             for i in range(block_context['index'], len(block_context['items'])):
@@ -94,4 +94,4 @@ class MultiThreadLoop(Block):
 
     @classmethod
     def get_node_statement(cls, node):
-        return node.find("./b:statement[@name='loop']", cls.ns)
+        return node.find("./b:statement", cls.ns)
