@@ -71,14 +71,14 @@ class Context:
 
     def to_parallel_dict(self):
         return dict(
-            var=self.variables,
+            variables=self.variables,
             debug=self.block_context,
             operation=self.operation,
         )
 
     def to_dict(self):
         return dict(
-            var=self.variables,
+            variables=self.variables,
             debug=self.block_context,
             operation=self.operation,
             deferred=self.deferred,
